%define soversion %(echo %version | cut -d. -f1-2)
%define fullversion %(echo %version | tr -d [:alpha:])
Name:          openssl
Version:       1.1.1f
Release:       1mamba
Summary:       Secure Sockets Layer communications libs and utils
Group:         Network/Security
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           http://www.openssl.org
Source:        https://www.openssl.org/source/openssl-%{version}.tar.gz
Source1:       openssl-makecerts
Patch0:        %{name}-1.0.1a-fix_non_ia32.patch
Patch1:        openssl-1.0.2a-version.patch
License:       BSD
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libz-devel
## AUTOBUILDREQ-END
BuildRequires: perl-WWW-Curl
BuildRequires: perl-devel
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}
BuildRoot:     %{_tmppath}/%{name}-%{version}-root

%description
The openssl certificate management tool and the shared libraries that provide various encryption and decription algorithms and protocols, including DES, RC4, RSA and SSL.
This product includes software developed by the OpenSSL Project for use in the OpenSSL Toolkit (http://www.openssl.org/).
This product includes cryptographic software written by Eric Young (eay@cryptsoft.com).
This product includes software written by Tim Hudson (tjh@cryptsoft.com).

%package -n lib%{name}
Summary:       Library for OpenSSL
Group:         System/Libraries

%description -n lib%{name}
The libraries files are needed for various cryptographic algorithms and protocols, including DES, RC4, RSA and SSL.
This product includes software developed by the OpenSSL Project for use in the OpenSSL Toolkit (http://www.openssl.org/).
This product includes cryptographic software written by Eric Young (eay@cryptsoft.com).
This product includes software written by Tim Hudson (tjh@cryptsoft.com).

%package -n lib%{name}-devel
Summary:       Library Devel for OpenSSL
Group:         Development/Libraries
Requires:      lib%{name} = %{version}-%{release}
Obsoletes:     libopenssl097-devel

%description -n lib%{name}-devel
Library symlinks and include files needed to compile apps with support for various cryptographic algorithms and protocols, including DES, RC4, RSA and SSL.
This product includes software developed by the OpenSSL Project for use in the OpenSSL Toolkit (http://www.openssl.org/).
This product includes cryptographic software written by Eric Young (eay@cryptsoft.com).
This product includes software written by Tim Hudson (tjh@cryptsoft.com).

%package -n lib%{name}-static
Summary:       OpenSSL static libraries
Group:         Development/Libraries
Requires:      lib%{name} = %{version}-%{release}
Requires:      lib%{name}-devel = %{version}-%{release}

%description -n lib%{name}-static
Static libraries needed to compile apps with support for various cryptographic algorithms and protocols, including DES, RC4, RSA and SSL.

%debug_package

%prep
%setup -q -n openssl-%{version}
#%patch0 -p1

# Using Fedora versioning patch
#%patch1 -p1
#sed -i 's/SHLIB_VERSION_NUMBER "1.0.0"/SHLIB_VERSION_NUMBER "%{version}"/' crypto/opensslv.h

%build
# FIXME: --openssldir=%{_libdir}/ssl
# (FHS: no executable files should be installed in /etc)
./Configure \
%ifarch ppc
    linux-ppc \
%endif
%ifarch i586
    linux-elf \
%endif
%ifarch x86_64
    linux-x86_64 \
	enable-ec_nistp_64_gcc_128 \
%endif
%ifarch arm
    linux-generic32 \
%endif
    shared \
    enable-md2 \
    --prefix=%{_prefix} \
    --openssldir=%{_sysconfdir}/ssl \
	zlib enable-camellia enable-seed enable-rfc3779 enable-sctp \
	enable-cms enable-md2 enable-rc5 enable-ssl3 enable-ssl3-method \
	enable-weak-ssl-ciphers \
	shared
	
#	no-mdc2 no-ec2m no-sm2 no-sm4 \
#${sslarch} $RPM_OPT_FLAGS '-DDEVRANDOM="\"/dev/urandom\""'

%ifarch ppc
sed -i "s/-m486/-march=%{_target_cpu}/g" Makefile
%endif

sed -i 's|\(.*\)chmod 644\(.*/lib/pkgconfig\)|\1chmod 755\2|' Makefile

%make -j1 CC=%{_host}-gcc MANDIR=%{_mandir}
#% make -j1 CC=%{_host}-gcc rehash

#export LD_LIBRARY_PATH=`pwd`${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
#%if "%{_host}" == "%{_build}"
#make test
#%endif

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

# Clean up the .pc files
for i in libcrypto.pc libssl.pc openssl.pc ; do
  sed -i '/^Libs.private:/{s/-L[^ ]* //;s/-Wl[^ ]* //}' $i
done

%makeinstall

rename so.%{soversion} so.%{fullversion} %{buildroot}%{_libdir}/*.so.%{soversion}
for lib in %{buildroot}%{_libdir}/*.so.%{fullversion} ; do
	chmod 755 ${lib}
	ln -s -f `basename ${lib}` $RPM_BUILD_ROOT%{_libdir}/`basename ${lib} .%{fullversion}`
	ln -s -f `basename ${lib}` $RPM_BUILD_ROOT%{_libdir}/`basename ${lib} .%{fullversion}`.%{soversion}
done

chmod 755 %{buildroot}%{_libdir}/pkgconfig
chmod 644 %{buildroot}%{_libdir}/pkgconfig/*.pc

mv %{buildroot}%{_mandir}/man1/passwd.* \
   %{buildroot}%{_mandir}/man1/openssl-passwd.*
#mv %{buildroot}%{_mandir}/man3/err.* \
#   %{buildroot}%{_mandir}/man3/openssl-err.*
#mv %{buildroot}%{_mandir}/man3/rand.* \
#   %{buildroot}%{_mandir}/man3/openssl-rand.*
# rpmbuild can't correctly handle spaces in symlink names
#rm -f %{buildroot}%{_mandir}/man7/Modes\ of\ DES.7

mkdir -p %{buildroot}/var/ssl/{certs,newcerts,private,crl}
touch %{buildroot}/var/ssl/index.txt
echo "01" > %{buildroot}/var/ssl/serial

sed -i "s|./demoCA|/var/ssl|" %{buildroot}%{_sysconfdir}/ssl/openssl.cnf

rm -f %{buildroot}%{_libdir}/fips_premain.c
rm -f %{buildroot}%{_libdir}/fips_premain.c.sha1
rm -f %{buildroot}%{_mandir}/man3/.3*

install -m 0755 -D %{SOURCE1} %{buildroot}%{_sbindir}/openssl-makecerts

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/ssl/openssl.cnf
%{_sysconfdir}/ssl/ct_log_list.cnf
%{_sysconfdir}/ssl/ct_log_list.cnf.dist
%{_sysconfdir}/ssl/openssl.cnf.dist
%dir %{_sysconfdir}/ssl/private
%{_sysconfdir}/ssl/misc
%{_bindir}/c_rehash
#%{_bindir}/fipsld
%{_bindir}/openssl
%{_sbindir}/openssl-makecerts
#%{_bindir}/openssl_fips_fingerprint
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man7/*
%dir /var/ssl
%dir /var/ssl/certs
%dir /var/ssl/crl
%dir /var/ssl/newcerts
%dir %attr(0700,root,root) /var/ssl/private
%config(noreplace) /var/ssl/index.txt
%config(noreplace) /var/ssl/serial

%files -n lib%{name}
%defattr(-,root,root)
%{_libdir}/libcrypto.so.*
%{_libdir}/libssl.so.*
%dir %{_libdir}/engines-%{soversion}
%{_libdir}/engines-%{soversion}/*.so
%doc LICENSE

%files -n lib%{name}-devel
%defattr(-,root,root)
%dir %{_includedir}/openssl
%{_includedir}/openssl/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/libcrypto.pc
%{_libdir}/pkgconfig/libssl.pc
%{_libdir}/pkgconfig/openssl.pc
%{_mandir}/man3/*
%dir %{_datadir}/doc/openssl
%{_datadir}/doc/openssl/*
%doc CHANGES* FAQ NEWS README* 

%files -n lib%{name}-static
%defattr(-,root,root)
%{_libdir}/*.a

%changelog
* Tue Mar 31 2020 Automatic Build System <autodist@mambasoft.it> 1.1.1f-1mamba
- automatic version update by autodist

* Tue Mar 17 2020 Automatic Build System <autodist@mambasoft.it> 1.1.1e-1mamba
- automatic version update by autodist

* Wed Sep 11 2019 Automatic Build System <autodist@mambasoft.it> 1.1.1d-1mamba
- automatic version update by autodist

* Wed May 29 2019 Automatic Build System <autodist@mambasoft.it> 1.1.1c-1mamba
- automatic version update by autodist

* Wed Feb 27 2019 Automatic Build System <autodist@mambasoft.it> 1.1.1b-1mamba
- automatic version update by autodist

* Sat Dec 08 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1.1a-1mamba
- update to 1.1.1a

* Sun Sep 09 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.2p-1mamba
- update to 1.0.2p

* Thu Dec 07 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.2m-1mamba
- update to 1.0.2m

* Wed May 04 2016 Automatic Build System <autodist@mambasoft.it> 1.0.2h-1mamba
- automatic version update by autodist

* Sat Apr 30 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.2g-3mamba
- /etc and /var files moved from libopenssl to openssl

* Sat Apr 30 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.2g-2mamba
- rebuilt after updating versioning patch (from Fedora)

* Tue Mar 01 2016 Automatic Build System <autodist@mambasoft.it> 1.0.2g-1mamba
- automatic version update by autodist

* Thu Jan 28 2016 Automatic Build System <autodist@mambasoft.it> 1.0.2f-1mamba
- automatic version update by autodist

* Fri Dec 04 2015 Automatic Build System <autodist@mambasoft.it> 1.0.2e-2mamba
- automatic version update by autodist

* Fri Dec 04 2015 Automatic Build System <autodist@mambasoft.it> 1.0.2e-1mamba
- automatic version update by autodist

* Thu Jul 09 2015 Automatic Build System <autodist@mambasoft.it> 1.0.2d-1mamba
- automatic version update by autodist

* Sat Jun 13 2015 Automatic Build System <autodist@mambasoft.it> 1.0.2c-1mamba
- automatic version update by autodist

* Fri Jun 12 2015 Automatic Build System <autodist@mambasoft.it> 1.0.2b-2mamba
- automatic version update by autodist

* Fri Jun 12 2015 Automatic Build System <autodist@mambasoft.it> 1.0.2b-1mamba
- automatic version update by autodist

* Mon Apr 27 2015 Automatic Build System <autodist@mambasoft.it> 1.0.2a-2mamba
- automatic version update by autodist

* Mon Apr 27 2015 Automatic Build System <autodist@mambasoft.it> 1.0.2a-1mamba
- automatic version update by autodist

* Tue Mar 10 2015 Automatic Build System <autodist@mambasoft.it> 1.0.2-1mamba
- automatic version update by autodist

* Fri Jan 16 2015 Automatic Build System <autodist@mambasoft.it> 1.0.1l-1mamba
- automatic version update by autodist

* Fri Jan 09 2015 Automatic Build System <autodist@mambasoft.it> 1.0.1k-1mamba
- automatic version update by autodist

* Thu Oct 16 2014 Automatic Build System <autodist@mambasoft.it> 1.0.1j-1mamba
- automatic version update by autodist

* Thu Aug 07 2014 Automatic Build System <autodist@mambasoft.it> 1.0.1i-1mamba
- automatic version update by autodist

* Sat Jul 26 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.1h-2mamba
- x86_64: rebuild with enable-ec_nistp_64_gcc_128 as suggested by tor

* Fri Jun 06 2014 Automatic Build System <autodist@mambasoft.it> 1.0.1h-1mamba
- automatic version update by autodist

* Tue Apr 08 2014 Automatic Build System <autodist@mambasoft.it> 1.0.1g-1mamba
- automatic version update by autodist

* Sun Feb 09 2014 Automatic Build System <autodist@mambasoft.it> 1.0.1f-1mamba
- automatic version update by autodist

* Fri Nov 15 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.1e-3mamba
- added openssl-static subpackage

* Thu Jun 27 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.1e-2mamba
- man and doc pages moved to appropriate subpackage
- don't provide 1.0.0 lib compatibility links (use now openssl100 legacy package)

* Tue Feb 12 2013 Automatic Build System <autodist@mambasoft.it> 1.0.1e-1mamba
- automatic version update by autodist

* Fri Feb 08 2013 Automatic Build System <autodist@mambasoft.it> 1.0.1d-1mamba
- automatic version update by autodist

* Mon Jul 02 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.1c-2mamba
- addded patch to enable symbol versioning

* Sat May 12 2012 Automatic Build System <autodist@mambasoft.it> 1.0.1c-1mamba
- automatic version update by autodist

* Fri Apr 20 2012 Automatic Build System <autodist@mambasoft.it> 1.0.1a-1mamba
- automatic version update by autodist

* Thu Mar 15 2012 Automatic Build System <autodist@mambasoft.it> 1.0.1-1mamba
- automatic version update by autodist

* Tue Mar 13 2012 Automatic Build System <autodist@mambasoft.it> 1.0.0h-1mamba
- automatic version update by autodist

* Thu Jan 19 2012 Automatic Build System <autodist@mambasoft.it> 1.0.0g-1mamba
- automatic version update by autodist

* Thu Jan 05 2012 Automatic Build System <autodist@mambasoft.it> 1.0.0f-1mamba
- automatic version update by autodist

* Tue Sep 06 2011 Automatic Build System <autodist@mambasoft.it> 1.0.0e-1mamba
- automatic version update by autodist

* Mon Mar 14 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.0d-2mamba
- rebuilt with debug package

* Wed Feb 09 2011 Automatic Build System <autodist@mambasoft.it> 1.0.0d-1mamba
- automatic update by autodist

* Mon Dec 06 2010 Automatic Build System <autodist@mambasoft.it> 1.0.0c-1mamba
- automatic update to 1.0.0c by autodist

* Fri Jul 02 2010 Davide Madrisan <davide.madrisan@gmail.com> 1.0.0a-2mamba
- enable md2 support

* Wed Jun 02 2010 Automatic Build System <autodist@mambasoft.it> 1.0.0a-1mamba
- automatic update to 1.0.0a by autodist

* Tue Mar 30 2010 Automatic Build System <autodist@mambasoft.it> 1.0.0-1mamba
- automatic update to 1.0.0 by autodist

* Mon Mar 29 2010 Automatic Build System <autodist@mambasoft.it> 0.9.8n-1mamba
- automatic update to 0.9.8n by autodist

* Tue Mar 23 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8m-2mamba
- move /etc/ssl/misc to openssl package
- removed build requirement for perl
- add support for arm target

* Fri Feb 26 2010 Automatic Build System <autodist@mambasoft.it> 0.9.8m-1mamba
- automatic update to 0.9.8m by autodist

* Wed Nov 18 2009 Automatic Build System <autodist@mambasoft.it> 0.9.8l-1mamba
- automatic update to 0.9.8l by autodist

* Fri Mar 27 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8k-1mamba
- automatic update to 0.9.8k by autodist

* Wed Jan 07 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8j-1mamba
- automatic update to 0.9.8j by autodist

* Sat Oct 04 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8i-2mamba
- libopenssl-devel: obsolete libopenssl097-devel
- set 700 permission to /var/ssl/private directory

* Tue Sep 16 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8i-1mamba
- automatic update to 0.9.8i by autodist

* Tue Jun 17 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8h-1mamba
- update to 0.9.8h

* Fri Mar 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8g-3mamba
- added openssl-makecerts script for creating a CA and a self-signed certificate

* Mon Dec 31 2007 Aleph0 <aleph0@openmamba.org> 0.9.8g-2mamba
- fix permissions of .pc files

* Sun Nov 18 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8g-1mamba
- update to 0.9.8g

* Wed Sep 06 2006 Davide Madrisan <davide.madrisan@qilinux.it> 0.9.7k-1qilnx
- update to version 0.9.7k by autospec
- also fixes CAN-2006-4339 (bugzilla#230)

* Fri Oct 14 2005 Davide Madrisan <davide.madrisan@qilinux.it> 0.9.7h-1qilnx
- update to version 0.9.7h by autospec
- also fixes the security issue QSA-2005-119 (CAN-2005-2969)
- patches removed (merget upstream)

* Wed Jul 27 2005 Davide Madrisan <davide.madrisan@qilinux.it> 0.9.7e-2qilnx
- fix security issue QSA-2005-083 (CAN-2005-0109)
- do not create a broken link to the libfips library (p0)
  see http://www.mail-archive.com/openssl-dev%40openssl.org/msg18268.html

* Tue Dec 14 2004 Davide Madrisan <davide.madrisan@qilinux.it> 0.9.7e-1qilnx
- update to version 0.9.7e by autospec
- fix security issue QSA-2004-062 (CAN-2004-0975)
- added documentation

* Thu Mar 18 2004 Davide Madrisan <davide.madrisan@qilinux.it> 0.9.7d-1qilnx
- security fix release (CAN-2004-0079, CAN-2004-0112)

* Mon Jan 19 2004 Davide Madrisan <davide.madrisan@qilinux.it> 0.9.7c-2qilnx
- specfile fixes

* Wed Oct 01 2003 Davide Madrisan <davide.madrisan@qilinux.it> 0.9.7c-1qilnx
- rebuilt with new version (important security bugfixes)

* Fri Jul 25 2003 Silvan Calarco <silvan.calarco@qinet.it> 0.9.7b-4qilnx
- configured so that certificates are by default under /var/ssl

* Wed Jun 18 2003 Silvan Calarco <silvan.calarco@qinet.it> 0.9.7b-3qilnx
- rebuilt against gcc 3.2.3
- files correctly redistributed beetwen main and devel package

* Wed Apr 30 2003 Silvan Calarco <silvan.calarco@qinet.it>
- err, rand and passwd manpages renamed to openssl-* to avoid conflicts with other versions

* Tue Apr 16 2003 Luca Tinelli <luca.tinelli@qinet.it>
- first build
